@@ -10,45 +10,45 @@
 #' other variables over the same intervals, more insight can be gained into the
 #' underlying reasons why model performance is poor.
 #'
-#' The \code{conditionalEval} function provides information on how other
+#' The `conditionalEval` function provides information on how other
 #' variables vary across the same intervals as shown on the conditional quantile
 #' plot. There are two types of variable that can be considered by setting the
-#' value of \code{statistic}. First, \code{statistic} can be another variable in
+#' value of `statistic`. First, `statistic` can be another variable in
 #' the data frame. In this case the plot will show the different proportions of
-#' \code{statistic} across the range of predictions. For example \code{statistic
-#' = "season"} will show for each interval of \code{mod} the proportion of
+#' `statistic` across the range of predictions. For example `statistic
+#' = "season"` will show for each interval of `mod` the proportion of
 #' predictions that were spring, summer, autumn or winter. This is useful
 #' because if model performance is worse for example at high concentrations of
-#' \code{mod} then knowing that these tend to occur during a particular season
-#' etc. can be very helpful when trying to understand \emph{why} a model fails.
-#' See \code{\link{cutData}} for more details on the types of variable that can
-#' be \code{statistic}. Another example would be \code{statistic = "ws"} (if
+#' `mod` then knowing that these tend to occur during a particular season
+#' etc. can be very helpful when trying to understand *why* a model fails.
+#' See [cutData()] for more details on the types of variable that can
+#' be `statistic`. Another example would be `statistic = "ws"` (if
 #' wind speed were available in the data frame), which would then split wind
 #' speed into four quantiles and plot the proportions of each.
 #'
-#' Second, \code{conditionalEval} can simultaneously plot the model performance
-#' of other observed/predicted variable \bold{pairs} according to different
+#' Second, `conditionalEval` can simultaneously plot the model performance
+#' of other observed/predicted variable **pairs** according to different
 #' model evaluation statistics. These statistics derive from the
-#' \code{\link{modStats}} function and include \dQuote{MB}, \dQuote{NMB},
+#' [modStats()] function and include \dQuote{MB}, \dQuote{NMB},
 #' \dQuote{r}, \dQuote{COE}, \dQuote{MGE}, \dQuote{NMGE}, \dQuote{RMSE} and
-#' \dQuote{FAC2}. More than one statistic can be supplied e.g. \code{statistic =
-#' c("NMB", "COE")}. Bootstrap samples are taken from the corresponding values
+#' \dQuote{FAC2}. More than one statistic can be supplied e.g. `statistic =
+#' c("NMB", "COE")`. Bootstrap samples are taken from the corresponding values
 #' of other variables to be plotted and their statistics with 95\% confidence
-#' intervals calculated. In this case, the model \emph{performance} of other
-#' variables is shown across the same intervals of \code{mod}, rather than just
+#' intervals calculated. In this case, the model *performance* of other
+#' variables is shown across the same intervals of `mod`, rather than just
 #' the values of single variables. In this second case the model would need to
 #' provide observed/predicted pairs of other variables.
 #'
 #' For example, a model may provide predictions of NOx and wind speed (for which
-#' there are also observations available). The \code{conditionalEval} function
+#' there are also observations available). The `conditionalEval` function
 #' will show how well these other variables are predicted for the same intervals
 #' of the main variables assessed in the conditional quantile e.g. ozone. In
-#' this case, values are supplied to \code{var.obs} (observed values for other
-#' variables) and \code{var.mod} (modelled values for other variables). For
+#' this case, values are supplied to `var.obs` (observed values for other
+#' variables) and `var.mod` (modelled values for other variables). For
 #' example, to consider how well the model predicts NOx and wind speed
-#' \code{var.obs = c("nox.obs", "ws.obs")} and \code{var.mod = c("nox.mod",
-#' "ws.mod")} would be supplied (assuming \code{nox.obs, nox.mod, ws.obs,
-#' ws.mod} are present in the data frame). The analysis could show for example,
+#' `var.obs = c("nox.obs", "ws.obs")` and `var.mod = c("nox.mod",
+#' "ws.mod")` would be supplied (assuming `nox.obs, nox.mod, ws.obs,
+#' ws.mod` are present in the data frame). The analysis could show for example,
 #' when ozone concentrations are under-predicted, the model may also be shown to
 #' over-predict concentrations of NOx at the same time, or under-predict wind
 #' speeds. Such information can thus help identify the underlying causes of poor
@@ -58,43 +58,43 @@
 #' might suggest an over-estimate of NOx emissions. One or more additional
 #' variables can be plotted.
 #'
-#' A special case is \code{statistic = "cluster"}. In this case a data frame is
-#' provided that contains the cluster calculated by \code{\link{trajCluster}}
-#' and \code{\link{importTraj}}. Alternatively users could supply their own
+#' A special case is `statistic = "cluster"`. In this case a data frame is
+#' provided that contains the cluster calculated by [trajCluster()]
+#' and [importTraj()]. Alternatively users could supply their own
 #' pre-calculated clusters. These calculations can be very useful in showing
 #' whether certain back trajectory clusters are associated with poor (or good)
-#' model performance. Note that in the case of \code{statistic = "cluster"}
+#' model performance. Note that in the case of `statistic = "cluster"`
 #' there will be fewer data points used in the analysis compared with the
 #' ordinary statistics above because the trajectories are available for every
-#' three hours. Also note that \code{statistic = "cluster"} cannot be used
+#' three hours. Also note that `statistic = "cluster"` cannot be used
 #' together with the ordinary model evaluation statistics such as MB. The output
-#' will be a bar chart showing the proportion of each interval of \code{mod} by
+#' will be a bar chart showing the proportion of each interval of `mod` by
 #' cluster number.
 #'
 #' Far more insight can be gained into model performance through conditioning
-#' using \code{type}. For example, \code{type = "season"} will plot conditional
+#' using `type`. For example, `type = "season"` will plot conditional
 #' quantiles and the associated model performance statistics of other variables
-#' by each season. \code{type} can also be a factor or character field e.g.
+#' by each season. `type` can also be a factor or character field e.g.
 #' representing different models used.
 #'
 #' See Wilks (2005) for more details of conditional quantile plots.
 #'
 #' @inheritParams conditionalQuantile
 #' @param var.obs Other variable observations for which statistics should be
-#'   calculated. Can be more than length one e.g. \code{var.obs = c("nox.obs",
-#'   "ws.obs")}. Note that including other variables could reduce the number of
+#'   calculated. Can be more than length one e.g. `var.obs = c("nox.obs",
+#'   "ws.obs")`. Note that including other variables could reduce the number of
 #'   data available to plot due to the need of having non-missing data for all
 #'   variables.
 #' @param var.mod Other variable predictions for which statistics should be
-#'   calculated. Can be more than length one e.g. \code{var.obs = c("nox.obs",
-#'   "ws.obs")}.
-#' @param type \code{type} determines how the data are split i.e. conditioned,
+#'   calculated. Can be more than length one e.g. `var.obs = c("nox.obs",
+#'   "ws.obs")`.
+#' @param type `type` determines how the data are split i.e. conditioned,
 #'   and then plotted. The default is will produce a single plot using the
 #'   entire data. Type can be one of the built-in types as detailed in
-#'   \code{cutData} e.g. "season", "year", "weekday" and so on. For example,
-#'   \code{type = "season"} will produce four plots --- one for each season.
+#'   `cutData` e.g. "season", "year", "weekday" and so on. For example,
+#'   `type = "season"` will produce four plots --- one for each season.
 #'
-#'   It is also possible to choose \code{type} as another variable in the data
+#'   It is also possible to choose `type` as another variable in the data
 #'   frame. If that variable is numeric, then the data will be split into four
 #'   quantiles (if possible) and labelled accordingly. If type is an existing
 #'   character or factor variable, then those categories/levels will be used
@@ -102,34 +102,34 @@
 #'   different variables and how they depend on one another.
 #' @param statistic Statistic(s) to be plotted. Can be \dQuote{MB},
 #'   \dQuote{NMB}, \dQuote{r}, \dQuote{COE}, \dQuote{MGE}, \dQuote{NMGE},
-#'   \dQuote{RMSE} and \dQuote{FAC2}, as described in \code{modStats}. When
-#'   these statistics are chosen, they are calculated from \code{var.mod} and
-#'   \code{var.mod}.
+#'   \dQuote{RMSE} and \dQuote{FAC2}, as described in `modStats`. When
+#'   these statistics are chosen, they are calculated from `var.mod` and
+#'   `var.mod`.
 #'
-#'   \code{statistic} can also be a value that can be supplied to
-#'   \code{cutData}. For example, \code{statistic = "season"} will show how
+#'   `statistic` can also be a value that can be supplied to
+#'   `cutData`. For example, `statistic = "season"` will show how
 #'   model performance varies by season across the distribution of predictions
 #'   which might highlight that at high concentrations of NOx the model tends to
 #'   underestimate concentrations and that these periods mostly occur in winter.
-#'   \code{statistic} can also be another variable in the data frame --- see
-#'   \code{cutData} for more information. A special case is \code{statistic =
-#'   "cluster"} if clusters have been calculated using \code{trajCluster}.
+#'   `statistic` can also be another variable in the data frame --- see
+#'   `cutData` for more information. A special case is `statistic =
+#'   "cluster"` if clusters have been calculated using `trajCluster`.
 #' @param col.var Colours for the additional variables to be compared. See
-#'   \code{openColours} for more details.
+#'   `openColours` for more details.
 #' @param var.names Variable names to be shown on plot for plotting
-#'   \code{var.obs} and \code{var.mod}.
-#' @param ... Other graphical parameters passed onto \code{conditionalQuantile}
-#'   and \code{cutData}. For example, \code{conditionalQuantile} passes the
-#'   option \code{hemisphere = "southern"} on to \code{cutData} to provide
-#'   southern (rather than default northern) hemisphere handling of \code{type =
-#'   "season"}. Similarly, common axis and title labelling options (such as
-#'   \code{xlab}, \code{ylab}, \code{main}) are passed to \code{xyplot} via
-#'   \code{quickText} to handle routine formatting.
+#'   `var.obs` and `var.mod`.
+#' @param ... Other graphical parameters passed onto `conditionalQuantile`
+#'   and `cutData`. For example, `conditionalQuantile` passes the
+#'   option `hemisphere = "southern"` on to `cutData` to provide
+#'   southern (rather than default northern) hemisphere handling of `type =
+#'   "season"`. Similarly, common axis and title labelling options (such as
+#'   `xlab`, `ylab`, `main`) are passed to `xyplot` via
+#'   `quickText` to handle routine formatting.
 #' @import latticeExtra
 #' @export
 #' @author David Carslaw
 #' @family model evaluation functions
-#' @seealso The \code{verification} package for comprehensive functions for
+#' @seealso The `verification` package for comprehensive functions for
 #'   forecast verification.
 #' @references Wilks, D. S., 2005. Statistical Methods in the Atmospheric
 #'   Sciences, Volume 91, Second Edition (International Geophysics), 2nd
@@ -168,7 +168,6 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
 
   ## reset graphic parameters
   on.exit(trellis.par.set(
-
     fontsize = current.font
   ))
 
@@ -304,7 +303,6 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
       }
 
       if (nrow(x) > 4) {
-
         res <- group_by(data.frame(n = 1:200), n) %>%
           do(tmpFun(i = .$n, x))
 
@@ -327,7 +325,7 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
     }
 
     if (other) {
-    vars <- c("pred.cut", statistic)
+      vars <- c("pred.cut", statistic)
 
       res <- res %>%
         group_by(across(vars)) %>%
@@ -340,10 +338,9 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
         mutate(Freq = Freq / sum(Freq))
 
       res$statistic <- factor(statistic)
-
     } else {
       res <- group_by(res, pred.cut) %>% do(statFun(., statistic = statistic))
-    #  res <- do(statFun(., statistic = statistic))
+      #  res <- do(statFun(., statistic = statistic))
     }
 
     na.omit(res)
@@ -368,8 +365,9 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
       strip.left <- FALSE
     } else { ## two conditioning variables
 
-      pol.name <- sapply(levels(clust.results[, type[1]]), function(x)
-        quickText(x, auto.text))
+      pol.name <- sapply(levels(clust.results[, type[1]]), function(x) {
+        quickText(x, auto.text)
+      })
       strip.left <- strip.custom(factor.levels = pol.name)
     }
     ## #########################################################################
@@ -403,7 +401,6 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
         title = statistic, cex.title = 1
       ),
       par.strip.text = list(cex = 0.8),
-
       panel = function(x, ...) {
         ## set width of boxes depending on x-scale
         box.width <- diff(sort(unique(x)))[1]
@@ -417,7 +414,6 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
   statistic <- statistic[which(statistic %in% the.stats)]
 
   if (length(statistic) > 0) {
-
     # combinations of statistics and variables to process
     combs <- data.frame(
       expand.grid(
@@ -438,8 +434,10 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
 
     results <- combs %>%
       rowwise() %>%
-      do(suppressWarnings(process_data(mydata, type, statistic = .$stat,
-                      var.obs = .$var.obs, var.mod = .$var.mod)))
+      do(suppressWarnings(process_data(mydata, type,
+        statistic = .$stat,
+        var.obs = .$var.obs, var.mod = .$var.mod
+      )))
 
     results$.id <- as.numeric(as.character(results$pred.cut))
 
@@ -454,16 +452,19 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
 
     ## proper names of labelling ###############################################
 
-    pol.name <- sapply(levels(as.factor(results[["statistic"]])),
-                       function(x) quickText(x, auto.text))
+    pol.name <- sapply(
+      levels(as.factor(results[["statistic"]])),
+      function(x) quickText(x, auto.text)
+    )
     strip <- strip.custom(factor.levels = pol.name)
 
     if (type == "default") {
       strip.left <- FALSE
     } else { ## two conditioning variables
 
-      pol.name <- sapply(levels(results[[type[1]]]), function(x)
-        quickText(x, auto.text))
+      pol.name <- sapply(levels(results[[type[1]]]), function(x) {
+        quickText(x, auto.text)
+      })
 
       strip.left <- strip.custom(factor.levels = pol.name)
     }
@@ -479,8 +480,9 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
         col = myColors[1:length(var.obs)],
         lty = extra.args$lty, lwd = 2
       ),
-      text = list(lab = sapply(var.names, function(x)
-        quickText(x, auto.text)), cex = 1),
+      text = list(lab = sapply(var.names, function(x) {
+        quickText(x, auto.text)
+      }), cex = 1),
       space = "bottom", columns = 2,
       title = quickText("variable", auto.text), cex.title = 1
     )
@@ -506,7 +508,6 @@ conditionalEval <- function(mydata, obs = "obs", mod = "mod",
       strip = strip,
       strip.left = strip.left,
       scales = list(y = list(relation = "free", rot = 0)),
-
       par.strip.text = list(cex = 0.8),
       panel = panel.superpose, ...,
       panel.groups = function(x, y, group.number, subscripts, ...) {
