@@ -599,8 +599,13 @@ polarPlot <-
 
     # scale data by subtracting the min value this helps with dealing
     # with negative data on radial axis (starts from zero, always
-    # postive)
+    # positive)
+    
+    # return radial scale as attribute "radial_scale" on returned data for external plotting
+    radial_scale <- range(mydata[[x]])
+    
     mydata[[x]] <- mydata[[x]] - min(mydata[[x]], na.rm = TRUE)
+  
 
     # if more than one pollutant, need to stack the data and set type =
     # "variable" this case is most relevent for model-measurement
@@ -1068,7 +1073,7 @@ polarPlot <-
     labels <- pretty(c(mydata[[x]], upper) + min.scale)
     ## offset the lines/labels if necessary
     intervals <- intervals + (min(labels) - min.scale)
-
+    
     ## add zero in the middle if it exists
     if (min.scale != 0) {
       labels <- labels[-1]
@@ -1187,6 +1192,9 @@ polarPlot <-
     }
 
     newdata <- res
+    
+    # return attribute of scale used - useful for data with negative scales such as air_temp
+    attr(newdata, "radial_scale") <-  range(radial_scale)
     output <- list(plot = plt, data = newdata, call = match.call())
     class(output) <- "openair"
 
